@@ -949,7 +949,9 @@ what to do, ask your parent); it's also a speed critical method::
     sage: x._mul_.__module__
     'sage.categories.coercion_methods'
     sage: from six import get_method_function as gmf
-    sage: gmf(x._mul_) is gmf(Magmas.ElementMethods._mul_parent)
+    sage: gmf(x._mul_) is gmf(Magmas.ElementMethods._mul_parent)  # py2
+    True
+    sage: gmf(x._mul_) is Magmas.ElementMethods._mul_parent  # py3
     True
 
 ``product`` is a mathematical method implemented by the parent::
