@@ -2,19 +2,14 @@
 Gamma and related functions
 """
 from __future__ import print_function, absolute_import
-from six.moves import range
-from six import integer_types
 
 from sage.symbolic.function import GinacFunction, BuiltinFunction
-from sage.libs.pynac.pynac import (register_symbol, symbol_table,
-        py_factorial_py, I)
-from sage.structure.element import coercion_model
+from sage.libs.pynac.pynac import (register_symbol, symbol_table)
 from sage.structure.all import parent as s_parent
-from sage.symbolic.expression import Expression
-from sage.rings.all import Integer, Rational, RealField, ZZ, ComplexField
+from sage.rings.all import Rational, ComplexField
+from sage.rings.complex_number import is_ComplexNumber
 from sage.functions.exp_integral import Ei
 from sage.libs.mpmath import utils as mpmath_utils
-from sage.arith.all import binomial as arith_binomial
 from .log import exp
 from .other import sqrt
 from sage.symbolic.constants import pi
