@@ -704,6 +704,7 @@ def simplicial_data_from_kenzo_output(filename):
         dim_idx = new_dim_idx
     return simplex_data
 
+
 def HopfMap():
     r"""
     Return a simplicial model of the Hopf map `S^3 \to S^2`
@@ -739,9 +740,6 @@ def HopfMap():
     """
     # The 2-sphere and its simplices.
     S2 = Sphere(2)
-    v_0 = S2.n_cells(0)[0]
-    v_1 = v_0.apply_degeneracies(0)
-    v_2 = v_0.apply_degeneracies(0, 0)
     sigma = S2.n_cells(2)[0]
     s0_sigma = sigma.apply_degeneracies(0)
     s1_sigma = sigma.apply_degeneracies(1)
