@@ -29,15 +29,15 @@ AUTHORS:
   pexpect 4.0.1 + patches, see :trac:`10295`.
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2005 William Stein <wstein@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import print_function, absolute_import
 from six import string_types
 from six import reraise as raise_
@@ -58,7 +58,7 @@ import pexpect
 from pexpect import ExceptionPexpect
 from sage.interfaces.sagespawn import SageSpawn
 from sage.interfaces.interface import (Interface, InterfaceElement,
-            InterfaceFunction, InterfaceFunctionElement, AsciiArtString)
+            InterfaceFunction, InterfaceFunctionElement)
 
 from sage.structure.element import RingElement
 
@@ -138,7 +138,7 @@ class Expect(Interface):
         Interface.__init__(self, name)
 
         # Read environment variables
-        env_name = 'SAGE_%s_{}'%self.name().upper()
+        env_name = 'SAGE_%s_{}' % self.name().upper()
         if server is None:
             server = os.getenv(env_name.format('SERVER'))
         if server_tmpdir is None:
@@ -471,7 +471,7 @@ If this all works, you can then make calls like:
             print("Starting %s" % cmd.split()[0])
 
         if self.__remote_cleaner and self._server:
-            c = 'sage-native-execute  ssh %s "nohup sage -cleaner"  &'%self._server
+            c = 'sage-native-execute  ssh %s "nohup sage -cleaner"  &' % self._server
             os.system(c)
 
         # Unset some environment variables for the children to
@@ -798,10 +798,10 @@ If this all works, you can then make calls like:
                     self._synchronize()
                     return self._post_process_from_file(self._eval_line_using_file(line, restart_if_needed=False))
                 except RuntimeError as msg:
-                    raise RuntimeError('%s terminated unexpectedly while reading in a large line:\n%s'%(self,msg[0]))
+                    raise RuntimeError('%s terminated unexpectedly while reading in a large line:\n%s' % (self, msg.args[0]))
                 except TypeError:
                     pass
-            raise RuntimeError('%s terminated unexpectedly while reading in a large line'%self)
+            raise RuntimeError('%s terminated unexpectedly while reading in a large line' % self)
         except RuntimeError as msg:
             if self._quit_string() in line:
                 if self._expect is None or not self._expect.isalive():
@@ -814,10 +814,11 @@ If this all works, you can then make calls like:
                 except TypeError:
                     pass
                 except RuntimeError:
-                    raise RuntimeError('%s terminated unexpectedly while reading in a large line'%self)
-            if "Input/output error" in msg[0]:  # This occurs on non-linux machines
-                raise RuntimeError('%s terminated unexpectedly while reading in a large line'%self)
-            raise RuntimeError('%s terminated unexpectedly while reading in a large line:\n%s'%(self,msg[0]))
+                    raise RuntimeError('%s terminated unexpectedly while reading in a large line' % self)
+            if "Input/output error" in msg.args[0]:
+                # This occurs on non-linux machines
+                raise RuntimeError('%s terminated unexpectedly while reading in a large line' % self)
+            raise RuntimeError('%s terminated unexpectedly while reading in a large line:\n%s' % (self, msg.args[0]))
         return self._post_process_from_file(s)
 
     def _post_process_from_file(self, s):
@@ -917,7 +918,7 @@ If this all works, you can then make calls like:
             E = self._expect
             try:
                 if len(line) >= 4096:
-                    raise RuntimeError("Sending more than 4096 characters with %s on a line may cause a hang and you're sending %s characters"%(self, len(line)))
+                    raise RuntimeError("Sending more than 4096 characters with %s on a line may cause a hang and you're sending %s characters" % (self, len(line)))
                 E.sendline(line)
                 if not wait_for_prompt:
                     return ''
@@ -942,9 +943,9 @@ If this all works, you can then make calls like:
                         except (TypeError, RuntimeError):
                             pass
                         return self._eval_line(line,allow_use_file=allow_use_file, wait_for_prompt=wait_for_prompt, restart_if_needed=False)
-                raise_(RuntimeError, "%s\nError evaluating %s in %s"%(msg, line, self), sys.exc_info()[2])
+                raise_(RuntimeError, RuntimeError("%s\nError evaluating %s in %s" % (msg, line, self)), sys.exc_info()[2])
 
-            if len(line)>0:
+            if line:
                 try:
                     if isinstance(wait_for_prompt, string_types):
                         E.expect(str_to_bytes(wait_for_prompt))
@@ -981,7 +982,7 @@ If this all works, you can then make calls like:
                     out = ''
         except KeyboardInterrupt:
             self._keyboard_interrupt()
-            raise KeyboardInterrupt("Ctrl-c pressed while running %s"%self)
+            raise KeyboardInterrupt("Ctrl-c pressed while running %s" % self)
         if self._terminal_echo:
             i = out.find("\n")
             j = out.rfind("\r")
@@ -997,12 +998,12 @@ If this all works, you can then make calls like:
             except pexpect.ExceptionPexpect as msg:
                 raise pexpect.ExceptionPexpect( "THIS IS A BUG -- PLEASE REPORT. This should never happen.\n" + msg)
             self._start()
-            raise KeyboardInterrupt("Restarting %s (WARNING: all variables defined in previous session are now invalid)"%self)
+            raise KeyboardInterrupt("Restarting %s (WARNING: all variables defined in previous session are now invalid)" % self)
         else:
             self._expect.sendline(chr(3))  # send ctrl-c
             self._expect.expect(self._prompt)
             self._expect.expect(self._prompt)
-            raise KeyboardInterrupt("Ctrl-c pressed while running %s"%self)
+            raise KeyboardInterrupt("Ctrl-c pressed while running %s" % self)
 
     def interrupt(self, tries=5, timeout=2.0, quit_on_fail=True):
         E = self._expect
@@ -1139,14 +1140,14 @@ If this all works, you can then make calls like:
 
             sage: t = walltime()
             sage: try:
-            ....:    singular._expect_expr('25', timeout=0.5)
+            ....:    singular._expect_expr('25', timeout=float(0.4))
             ....: except Exception:
             ....:    print('Did not get expression')
             Did not get expression
 
         A quick consistency check on the time that the above took::
 
-            sage: w = walltime(t); w > 0.4 and w < 10
+            sage: w = walltime(t); 0.3 < w < 2
             True
 
         We tell Singular to print abc, which equals 25.
@@ -1192,9 +1193,9 @@ If this all works, you can then make calls like:
             if i > 0:
                 v = self._before()
                 self.quit()
-                raise ValueError("%s\nComputation failed due to a bug in %s -- NOTE: Had to restart."%(v, self))
+                raise ValueError("%s\nComputation failed due to a bug in %s -- NOTE: Had to restart." % (v, self))
         except KeyboardInterrupt:
-            print("Control-C pressed. Interrupting %s. Please wait a few seconds..."%self)
+            print("Control-C pressed. Interrupting %s. Please wait a few seconds..." % self)
             self.interrupt()
             raise
 
