@@ -96,6 +96,7 @@ from itertools import combinations
 from sage.rings.integer import Integer
 from sage.sets.disjoint_set import DisjointSet
 
+
 class GraphicMatroid(Matroid):
     r"""
     The graphic matroid class.
@@ -203,7 +204,7 @@ class GraphicMatroid(Matroid):
 
         # Map vertices on input graph to vertices in self._G
         self._vertex_map = {v: v for v in G.vertex_iterator()}
-        comps = G.connected_components()
+        comps = G.connected_components(sort=False)
         while len(comps) > 1:
             comp = comps.pop()
             v1 = comps[-1][-1]
@@ -289,7 +290,7 @@ class GraphicMatroid(Matroid):
         # This counts components:
         DS_vertices = DisjointSet(vertices)
         for (u, v, l) in edges:
-            DS_vertices.union(u,v)
+            DS_vertices.union(u, v)
         return (len(vertices) - DS_vertices.number_of_subsets())
 
     # Representation:
@@ -673,7 +674,7 @@ class GraphicMatroid(Matroid):
                 # then use method from abstract matroid class
                 conset, delset = sanitize_contractions_deletions(self, contractions, deletions)
                 M = self.minor(contractions=conset, deletions=delset)
-                (should_be_true, elements) =  Matroid._has_minor(M, N, certificate=True)
+                should_be_true, elements = Matroid._has_minor(M, N, certificate=True)
 
                 # elements is a tuple (contractions, deletions, dict)
                 # There should be no more contractions
@@ -712,13 +713,12 @@ class GraphicMatroid(Matroid):
             sage: M._corank([1,2,3])
             3
         """
-        edges = self.groundset_to_edges(X)
         all_vertices = self._G.vertices()
         not_our_edges = self.groundset_to_edges(self._groundset.difference(X))
         DS_vertices = DisjointSet(all_vertices)
-        for (u, v, l) in not_our_edges:
+        for u, v, l in not_our_edges:
             DS_vertices.union(u, v)
-        return (len(X) - (DS_vertices.number_of_subsets() - Integer(1)))
+        return len(X) - (DS_vertices.number_of_subsets() - Integer(1))
 
     def _is_circuit(self, X):
         """
@@ -834,7 +834,7 @@ class GraphicMatroid(Matroid):
         DS_vertices = DisjointSet(vertices)
         for (u, v, l) in edges:
             if DS_vertices.find(u) != DS_vertices.find(v):
-                DS_vertices.union(u,v)
+                DS_vertices.union(u, v)
                 our_set.add(l)
         return frozenset(our_set)
 
@@ -929,12 +929,11 @@ class GraphicMatroid(Matroid):
             set([v for (u, v, l) in edges]))
         edge_set = set()
         DS_vertices = DisjointSet(vertices)
-        for (u, v, l) in edges:
+        for u, v, l in edges:
             edge_set.add((u, v, l))
             if DS_vertices.find(u) != DS_vertices.find(v):
                 DS_vertices.union(u, v)
             else:
-                last_edge = (u, v, l)
                 break
         else:
             raise ValueError("no circuit in independent set")
@@ -1113,7 +1112,19 @@ class GraphicMatroid(Matroid):
             M = self.regular_matroid()
             if isinstance(other, GraphicMatroid):
                 other = other.regular_matroid()
-            return M._is_isomorphic(other, certificate=certificate)
+            if certificate:
+                # iso0: isomorphism from M and self -- in this order,
+                # to prevent an infinite recursion.
+                iso0 = M._is_isomorphic(self, certificate=certificate)[1]
+                # Now invert iso0 to get iso1, an isomorphism from self to M.
+                iso1 = {iso0[e]: e for e in iso0}
+                # iso2: isomorphism from M and other.
+                isomorphic, iso2 = M._is_isomorphic(other, certificate=certificate)
+                if not isomorphic:
+                    return (False, None)
+                # Compose iso1 and iso2, to go from self to other.
+                return (True, {e: iso2[iso1[e]] for e in iso1})
+            return M._is_isomorphic(other)
 
     def _isomorphism(self, other):
         """
@@ -1148,8 +1159,9 @@ class GraphicMatroid(Matroid):
             sage: M._isomorphism(N)
             {'a': 2, 'b': 4, 'c': 5, 'd': 0, 'e': 1, 'f': 3}
             sage: O = Matroid(Graph(edgelist), regular=True)
-            sage: M._isomorphism(O)
-            {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'e', 'e': 'd', 'f': 'f'}
+            sage: iso = M._isomorphism(O)
+            sage: M.is_isomorphism(O, iso)
+            True
         """
         return self.is_isomorphic(other, certificate=True)[1]
 
@@ -1219,16 +1231,16 @@ class GraphicMatroid(Matroid):
             [(0, 1, 0),
              (0, 2, 1),
              (1, 2, 2),
-             (2, 4, 3),
-             (2, 5, 4),
+             (1, 4, 3),
+             (1, 5, 4),
              (4, 5, 5),
-             (5, 7, 6),
-             (5, 8, 7),
+             (4, 7, 6),
+             (4, 8, 7),
              (7, 8, 8),
              (7, 8, 9),
              (8, 8, 10)]
             sage: M.vertex_map()
-            {0: 0, 1: 1, 2: 2, 3: 2, 4: 4, 5: 5, 6: 5, 7: 7, 8: 8}
+            {0: 0, 1: 1, 2: 2, 3: 1, 4: 4, 5: 5, 6: 4, 7: 7, 8: 8}
         """
         return copy(self._vertex_map)
 
@@ -1739,7 +1751,7 @@ class GraphicMatroid(Matroid):
         # If a vertex has degree 1, or 2, or 3, we already handled it.
         for u in vertices:
             if G.degree(u) > 3:
-                elts_incident = [l for (u0, v0, l) in G.edges_incident(u)]
+                elts_incident = [ll for (_, _, ll) in G.edges_incident(u)]
                 x = elts_incident.pop()
                 for i in range(1, (len(elts_incident) - Integer(1))):
                     groups = combinations(elts_incident, i)
@@ -1858,7 +1870,6 @@ class GraphicMatroid(Matroid):
             G.add_edge(u, v, l)
         return GraphicMatroid(G)
 
-
     def one_sum(self, X, u, v):
         """
         Arrange matroid components in the graph.
