@@ -411,10 +411,15 @@ class BackendIPythonCommandline(BackendIPython):
             sage: backend.threejs_offline_scripts()
             '...<script ...</script>...'
         """
-        from sage.env import SAGE_SHARE
+        from sage.env import THREEJS_DIR
 
-        scripts = [os.path.join(SAGE_SHARE, 'threejs', script)
-                   for script in ['three.min.js', 'OrbitControls.js']]
+        scripts = [
+            os.path.join(THREEJS_DIR, script)
+            for script in [
+                'build/three.min.js',
+                'examples/js/controls/OrbitControls.js',
+            ]
+        ]
 
         if sys.platform == 'cygwin':
             import cygwin
@@ -594,13 +599,13 @@ class BackendIPythonNotebook(BackendIPython):
             sage: from sage.repl.rich_output.backend_ipython import BackendIPythonNotebook
             sage: backend = BackendIPythonNotebook()
             sage: backend.threejs_offline_scripts()
-            '...<script src="/nbextensions/threejs/three.min...<\\/script>...'
+            '...<script src="/nbextensions/threejs/build/three.min...<\\/script>...'
         """
         from sage.repl.rich_output import get_display_manager
         CDN_scripts = get_display_manager().threejs_scripts(online=True)
         return """
-<script src="/nbextensions/threejs/three.min.js"></script>
-<script src="/nbextensions/threejs/OrbitControls.js"></script>
+<script src="/nbextensions/threejs/build/three.min.js"></script>
+<script src="/nbextensions/threejs/examples/js/controls/OrbitControls.js"></script>
 <script>
   if ( !window.THREE ) document.write('{}');
 </script>
