@@ -50,6 +50,7 @@ from __future__ import absolute_import
 import random
 
 from sage.misc.cachefunc import cached_method
+from sage.misc.latex import latex
 
 from sage.arith.all import lcm
 
@@ -155,6 +156,74 @@ class FunctionFieldDivisor(ModuleElement):
         ModuleElement.__init__(self, parent)
         self._data = data
 
+    def __hash__(self):
+        """
+        Return the hash of the divisor.
+
+        EXAMPLES::
+
+            sage: K.<x> = FunctionField(GF(2)); R.<t> = K[]
+            sage: F.<y> = K.extension(t^3 - x^2*(x^2 + x + 1)^2)
+            sage: f = x/(y+1)
+            sage: d = f.divisor()
+            sage: {d: 1}
+            {Place (1/x, 1/x^4*y^2 + 1/x^2*y + 1)
+              + Place (1/x, 1/x^2*y + 1)
+              + 3*Place (x, (1/(x^3 + x^2 + x))*y^2)
+              - 6*Place (x + 1, y + 1): 1}
+        """
+        return hash(tuple(sorted(self._data.items())))
+
+    def _format(self, formatter, mul, cr):
+        r"""
+        Return a string representation of ``self``.
+
+        This is used by both ``_repr_`` and ``_latex_`` methods.
+
+        INPUT:
+
+        - ``formatter`` -- either ``repr`` or ``latex``
+
+        - ``mul`` -- string inserted between multiplicity and place
+
+        - ``cr`` -- string inserted between places
+
+        TESTS::
+
+            sage: K.<x> = FunctionField(QQ)
+            sage: x.divisor()                # indirect doctest
+            - Place (1/x) + Place (x)
+            sage: latex(x.divisor())         # indirect doctest
+            - \left(\frac{1}{x}\right) + \left(x\right)
+        """
+        plus = ' + '
+        minus = ' - '
+
+        places = sorted(self._data)
+
+        if len(places) == 0:
+            return '0'
+
+        p = places.pop(0)
+        m = self._data[p]
+        if m == 1:
+            r = formatter(p)
+        elif m == -1:
+            r = '- ' + formatter(p) # seems more readable than `-`
+        else: # nonzero
+            r = formatter(m) + mul + formatter(p)
+        for p in places:
+            m = self._data[p]
+            if m == 1:
+                r += cr + plus + formatter(p)
+            elif m == -1:
+                r += cr + minus + formatter(p)
+            elif m > 0:
+                r += cr + plus + formatter(m) + mul + formatter(p)
+            elif m < 0:
+                r += cr + minus + formatter(-m) + mul + formatter(p)
+        return r
+
     def _repr_(self, split=True):
         """
         Return a string representation of the divisor.
@@ -173,39 +242,25 @@ class FunctionFieldDivisor(ModuleElement):
             'Place (1/x, 1/x^4*y^2 + 1/x^2*y + 1) + Place (1/x, 1/x^2*y + 1)
             + 3*Place (x, (1/(x^3 + x^2 + x))*y^2) - 6*Place (x + 1, y + 1)'
         """
-        mul = '*'
-        plus = ' + '
-        minus = ' - '
+        return self._format(repr, '*', '\n' if split else '')
 
-        if split:
-            cr = '\n'
-        else:
-            cr = ''
+    def _latex_(self):
+        r"""
+        Return the LaTeX representation of the divisor.
 
-        places = sorted(self._data)
+        EXAMPLES::
 
-        if len(places) == 0:
-            return '0'
-
-        p = places.pop(0)
-        m = self._data[p]
-        if m == 1:
-            r = repr(p)
-        elif m == -1:
-            r = '- ' + repr(p) # seems more readable than `-`
-        else: # nonzero
-            r = repr(m) + mul + repr(p)
-        for p in places:
-            m = self._data[p]
-            if m == 1:
-                r += cr + plus + repr(p)
-            elif m == -1:
-                r += cr + minus + repr(p)
-            elif m > 0:
-                r += cr + plus + repr(m) + mul + repr(p)
-            elif m < 0:
-                r += cr + minus + repr(-m) + mul + repr(p)
-        return r
+            sage: K.<x> = FunctionField(GF(2)); R.<t> = PolynomialRing(K)
+            sage: F.<y> = K.extension(t^3-x^2*(x^2+x+1)^2)
+            sage: f = x/(y+1)
+            sage: d = f.divisor()
+            sage: d._latex_()
+            \left(\frac{1}{x}, \frac{1}{x^{4}} y^{2} + \frac{1}{x^{2}} y + 1\right)
+             + \left(\frac{1}{x}, \frac{1}{x^{2}} y + 1\right)
+             + 3 \left(x, \left(\frac{1}{x^{3} + x^{2} + x}\right) y^{2}\right)
+             - 6 \left(x + 1, y + 1\right)
+        """
+        return self._format(latex, '', '')
 
     def _richcmp_(self, other, op):
         """
@@ -405,6 +460,8 @@ class FunctionFieldDivisor(ModuleElement):
             return 0
         return self._data[place]
 
+    valuation = multiplicity
+
     def degree(self):
         """
         Return the degree of the divisor.
@@ -531,7 +588,7 @@ class FunctionFieldDivisor(ModuleElement):
         return basis, coordinates_func
 
     def basis_differential_space(self):
-        """
+        r"""
         Return a basis of the space of differentials `\Omega(D)`
         for the divisor `D`.
 
@@ -554,7 +611,7 @@ class FunctionFieldDivisor(ModuleElement):
         return [W.element_class(W, f) for f in fbasis]
 
     def differential_space(self):
-        """
+        r"""
         Return the vector space of the differential space `\Omega(D)` of the divisor `D`.
 
         OUTPUT:
@@ -678,7 +735,7 @@ class FunctionFieldDivisor(ModuleElement):
         C = matrix([to(v) for v in I.gens_over_base()])
         M = C * B.inverse()
 
-        # Step 2.5: get the denonimator d of M and set mat = d * M
+        # Step 2.5: get the denominator d of M and set mat = d * M
         den = lcm([e.denominator() for e in M.list()])
         R = den.parent() # polynomial ring
         one = R.one()
