@@ -1285,7 +1285,7 @@ class ProjectiveSpace_field(ProjectiveSpace_ring):
         Bound check is strict for the rational field. Requires self to be projective space
         over a number field. Uses the
         Doyle-Krumm algorithm 4 (algorithm 5 for imaginary quadratic) for
-        computing algebraic numbers up to a given height [Doyle-Krumm]_.
+        computing algebraic numbers up to a given height [DK2013]_.
 
         The algorithm requires floating point arithmetic, so the user is
         allowed to specify the precision for such calculations.
